#
# spec file for package sacad
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sacad
Version:        2.8.0
Release:        1.1
Summary:        Search and download music album covers
License:        MPL-2.0
Group:          Development/Languages/Python
URL:            https://github.com/desbma/sacad
Source:         https://github.com/desbma/sacad/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
Requires:       python3-Pillow >= 2.7.0
Requires:       python3-Unidecode >= 1.1.1
Requires:       python3-aiohttp >= 3.6
Requires:       python3-appdirs >= 1.4.0
Requires:       python3-bitarray >= 0.8.3
Requires:       python3-cssselect >= 0.9.1
Requires:       python3-fake-useragent >= 0.1.11
Requires:       python3-lxml >= 4.0.0
Requires:       python3-mutagen >= 1.31
Requires:       python3-tqdm >= 4.28.1
Requires:       python3-web_cache >= 1.1.0
BuildArch:      noarch

%description
SACAD is a multi platform command line tool to download album covers
without manual intervention, ideal for integration in scripts, audio
players, etc.

%prep
%setup -q -n sacad-%{version}

%build
%python3_build

%install
%python3_install
find %{buildroot}/%{python3_sitelib}/sacad/ -name "*.py" -exec sed -i -e '/^#!\//, 1d' {} \;
%fdupes %{buildroot}/%{python3_sitelib}

#%%check
# disabled - tests require an internet connection

%files
%license LICENSE
%doc README.md
%{_bindir}/sacad
%{_bindir}/sacad_r
%{python3_sitelib}/sacad*

%changelog
* Tue Aug 13 2024 Dirk Müller <dmueller@suse.com>
- update to 2.8.0:
  * remove Amazon sources
  * fix: remove use of imhdr
  * boost exact album matches ranking for Deezer source
  * fix: path sanitization removing spaces
  * feat: add option to convert progressive JPEG to baseline
* Wed Oct 25 2023 ming li <mli@suse.com>
- update to 2.7.5:
  * fix workaround Amazon sources 503 error
* Mon Feb 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2.7.4:
  * crunch using oxipng if available
  * improve FLAC cover tag compatibility
  * update UA to fix Amazon sources 503 errors
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 2.7.3:
  * fix error logs when closing eventloop
  * exclude non-CD covers
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.7.2:
  * fix: remove fake-useragent dependency because of lack of API stability
  * fix: version fake-useragent cache file
  * fix: pre-commit URL
* Mon Nov 14 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.7.0
  * Support embedding album art in APEv2 tags
  * fix: unzip overwrite prompt
  * feat: allow choosing cover sources with -s/--cover-sources
  * feat: add Itunes cover source
  * officially support Python 3.10
  * drop Python 3.6 support
* Wed May 19 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.4.0
  * Fix embedding cover in files without tags
  * drop Python 3.5 + officially support Python 3.9
  * Set PIL flag to allow loading partial images
  * Improve handling of APEv2 tags
* Sat Oct 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.4
  * Workaround bitarray.bitdiff deprecation
* Fri Aug 21 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.3.3:
  * Fix tqdm_logging thread safety
* Wed Jul 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.2
  * Fix tests
* Sat Jun 13 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.0
  * Add Deezer cover source
* Sat Mar 21 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.3
- Use github source URL
* Fri Apr 26 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.9
* Fri Nov 17 2017 alarrosa@suse.com
- Initial version of sacad 1.9.0
